.. glidertest documentation master file, created by
   sphinx-quickstart on Tue Oct 29 11:30:19 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to glidertest's documentation!
======================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   demo-output.ipynb
   glidertest


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
